#!/usr/bin/gnuplot

set term 'epslatex' dashed lw 2 size 7.0 in, 4 in
set output 'chargino-pileup.tex'

set ytics axis in
set y2tics

set xlabel '$m$, GeV'
set ylabel '$\mathrm{d} \sigma / \mathrm{d} m$, ab/GeV'
set y2label 'Events/GeV' offset -1, 0

set key reverse left Left

set style fill solid 0.75

mmin = 80
mmax = 120

set label system( \
  sprintf( \
    "./integrate-events %f %f '$\\chi^+ \\chi^-$' plots/chargino/pileup/pu-nocut-χχ-2 '$\\mu^+ \\mu^-$' plots/chargino/pileup/pu-nocut-μμ-2 '$W^+ W^-$' plots/chargino/pileup/pu-nocut-ww-2 '$\\tau^+ \\tau^-$' plots/chargino/pileup/pu-nocut-ττ-2", \
    mmin, mmax \
  ) \
) at 5, 38

set arrow from mmin, graph 0 to mmin, graph 1 nohead front
set arrow from mmax, graph 0 to mmax, graph 1 nohead front

luminosity = 150e15

h = 60

plot [:150] [:h] [:] [: h * 1e-18 * luminosity] 'plots/chargino/pileup/stacked' \
        u 1:($5 * 1e18) w boxes lc rgb 'red' t '$pp \to pp \, \chi^+ \chi^-$', \
     '' u 1:($5 * luminosity) axes x1y2 w boxes lc rgb 'red' notitle, \
     '' u 1:($4 * 1e18) w boxes lc rgb 'blue' t '$pp \to pp \, \tilde \mu^+ \tilde \mu^-$', \
     '' u 1:($4 * luminosity) axes x1y2 w boxes lc rgb 'blue' notitle, \
     '' u 1:($3 * 1e18) w boxes lc rgb 'black' t '$pp \to pp \, W^+ W^- \to pp \, \mu^+ \nu \, \mu^- \bar \nu$', \
     '' u 1:($3 * luminosity) axes x1y2 w boxes lc rgb 'black' notitle, \
     '' u 1:($2 * 1e18) w boxes lc rgb 'dark-green' t '$pp \to pp \, \tau^+ \tau^- \to pp \, \mu^+ \nu_\mu \bar \nu_\tau \, \mu^- \bar \nu_\mu \nu_\tau$', \
     '' u 1:($2 * luminosity) axes x1y2 w boxes lc rgb 'dark-green' notitle
